summaryrefslogtreecommitdiff
path: root/include/gras/element.hpp
diff options
context:
space:
mode:
authorJosh Blum2013-07-06 17:02:24 -0700
committerJosh Blum2013-07-06 17:02:24 -0700
commitc6f6b12bf8429325407ae76f7ead8d3d72232f99 (patch)
tree6eb92f4630c4e911efa48d239a372b148c5e5e44 /include/gras/element.hpp
parent9ab885db8eb80c4046af20e1a361b304b5478686 (diff)
downloadsandhi-c6f6b12bf8429325407ae76f7ead8d3d72232f99.tar.gz
sandhi-c6f6b12bf8429325407ae76f7ead8d3d72232f99.tar.bz2
sandhi-c6f6b12bf8429325407ae76f7ead8d3d72232f99.zip
gras: locate_element since now elements have calls
Diffstat (limited to 'include/gras/element.hpp')
-rw-r--r--include/gras/element.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/gras/element.hpp b/include/gras/element.hpp
index 9b46d76..df47bef 100644
--- a/include/gras/element.hpp
+++ b/include/gras/element.hpp
@@ -105,7 +105,7 @@ struct GRAS_API Element : Callable, boost::shared_ptr<ElementImpl>
void adopt_element(const std::string &name, const Element &child);
/*!
- * Locate a block in the element tree hierarchy.
+ * Locate an element in the element tree hierarchy.
*
* Paths are unix style, absolte and relatives paths are possible.
* This call throws an invalid argument when bad paths are given.
@@ -113,10 +113,10 @@ struct GRAS_API Element : Callable, boost::shared_ptr<ElementImpl>
* Example path: /my_hier_block/my_block0
* Example path: ../my_block1
*
* \param path a path to a block (leaf) in the tree
* \return a pointer to the block
*/
- Block *locate_block(const std::string &path);
+ Element *locate_element(const std::string &path);
};
@@ -113,10 +113,10 @@ struct GRAS_API Element : Callable, boost::shared_ptr<ElementImpl>
* Example path: ../my_block1
*
- * \param path a path to a block (leaf) in the tree
- * \return a pointer to the block
+ * \param path a path to an element (leaf) in the tree
+ * \return a pointer to the element object
*/